@@ -4,4 +4,4 @@ from pybuilder.core import init
 
 @init
 def set_properties(project):
-    project.build_depends_on("flake8")
\ No newline at end of file
+    project.build_depends_on("django")
\ No newline at end of file
